@@ -3,12 +3,12 @@ context("genome_join_closest")
 
 library(dplyr)
 
-x1 <- data_frame(id = 1:4, bla=letters[1:4],
+x1 <- tibble(id = 1:4, bla=letters[1:4],
                  chromosome = c("chr1", "chr1", "chr2", "chr3"),
                  start = c(100, 200, 300, 400),
                  end = c(150, 250, 350, 450))
 
-x2 <- data_frame(id = 1:4, BLA=LETTERS[1:4],
+x2 <- tibble(id = 1:4, BLA=LETTERS[1:4],
                  chromosome = c("chr1", "chr1", "chr1", "chr2"),
                  start = c(220, 210, 300, 400),
                  end = c(225, 240, 320, 415))
